# Integration API
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/integration-api#overview)
  * [Advantages](https://help.sap.com/docs/leanix/ea/integration-api#advantages)
  * [Inbound and Outbound Data Processors](https://help.sap.com/docs/leanix/ea/integration-api#inbound-and-outbound-data-processors)
  * [LeanIX Data Interchange Format (LDIF)](https://help.sap.com/docs/leanix/ea/integration-api#leanix-data-interchange-format-\(ldif\))
  * [Mandatory Attributes](https://help.sap.com/docs/leanix/ea/integration-api#mandatory-attributes)
  * [Content Array](https://help.sap.com/docs/leanix/ea/integration-api#content-array)
  * [Integration REST API](https://help.sap.com/docs/leanix/ea/integration-api#integration-rest-api)
  * [Grouped Execution of Multiple Configurations](https://help.sap.com/docs/leanix/ea/integration-api#grouped-execution-of-multiple-configurations)
  * [Comments in Processors](https://help.sap.com/docs/leanix/ea/integration-api#comments-in-processors)


Overview of the Integration API.
